import ProcessUtil from '@/tools/process-util.js';
export default class Server extends ProcessUtil {

  constructor(params) {
    super(params);
  }

  /**
    * 根据值集代码查询值集
    */
   queryValueSetByCode(param) {
    return new Promise((resolve) => {
      $axios.get(`${process.env.API.baseURL}/sys/valueset/item/list/${param.code}`).then((response) => {
        let result = [];
        for (let item of response.data.dataResult) {
          result.push({ label: item.vsiValue, value: item.vsiKey });
        }
        resolve(result);
      }).catch((error) => {
        let responseData = { "dataResult": [], "extra": "", "msg": (error.response.data.message || "服务异常，请联系管理员"), "statusCode": "-1" };
        resolve(responseData);
      })
    })
  }

  /**
    * 根据值集代码和父值集代码查询值集
    */
  queryValueSetByCodeAndParentCode(param) {
    return new Promise((resolve) => {
      $axios.get(`${process.env.API.baseURL}/sys/valueset/item/list/${param.code}/${param.parentKey}`).then((response) => {
        let result = [];
        for (let item of response.data.dataResult) {
          result.push({ label: item.vsiValue, value: item.vsiKey });
        }
        resolve(result);
      }).catch((error) => {
        let responseData = { "dataResult": [], "extra": "", "msg": (error.response.data.message || "服务异常，请联系管理员"), "statusCode": "-1" };
        resolve(responseData);
      })
    })
  }

  /**
    * 查询归属公司
    */
   queryCompanys(param = {}) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.emsBaseDataURL}/mdOu/findCurrentMdOu`, param).then((response) => {
        resolve(response.data);
      }).catch((error) => {
        let responseData = { "dataResult": [], "extra": "", "msg": (error.response.data.message || "服务异常，请联系管理员"), "statusCode": "-1" };
        resolve(responseData);
      })
    })
  }

  /**
    * 查询付款类型
    */
   queryPayTypes(param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.emsBaseDataURL}/categoryconfig/findMappedValueSetItems/${param.categoryCode}/${param.code}`, param).then((response) => {
        let result = [];
        for (let item of response.data) {
          result.push({ label: item.vsiValue, value: item.vsiKey });
        }
        resolve(result);
      }).catch((error) => {
        let responseData = { "dataResult": [], "extra": "", "msg": (error.response.data.message || "服务异常，请联系管理员"), "statusCode": "-1" };
        resolve(responseData);
      })
    })
  }

  /**
    * 查询 查询类型
    */
   queryQueryTypes() {
    return this.queryValueSetByCode({code: 'queryType'});
  }

  /**
    * 查询供应商类型
    */
   queryVendorTypes() {
    return this.queryValueSetByCode({code: 'vendorType'});
  }

  /**
    * 查询币种
    */
   queryCurrencys() {
    return this.queryValueSetByCode({code: 'currency'});
  }

  /**
    * 查询请款类型（预计付款方式）
    */
   queryPaymentModes() {
    return this.queryValueSetByCode({code: 'paymentMode'});
  }
}